<?php

/**
 * @copyright   Copyright (C) 2005 - 2017 Michael Richey. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
defined('_JEXEC') or die;

JLoader::import('components.com_fields.libraries.fieldsplugin', JPATH_ADMINISTRATOR);

/**
 * Fields Location Plugin
 *
 * @since  3.7.0
 */
class PlgFieldsLocation extends FieldsPlugin
{
	public $apikey = false;
        public $scriptAdded = false;
        
	/**
	 * Transforms the field into a DOM XML element and appends it as a child on the given parent.
	 *
	 * @param   stdClass    $field   The field.
	 * @param   DOMElement  $parent  The field node parent.
	 * @param   JForm       $form    The form.
	 *
	 * @return  DOMElement
	 *
	 * @since   3.7.0
	 */
	public function onCustomFieldsPrepareDom($field, DOMElement $parent, JForm $form)
	{
		$fieldNode = parent::onCustomFieldsPrepareDom($field, $parent, $form);

		if (!$fieldNode)
		{
			return $fieldNode;
		}
		$fieldNode->setAttribute('readonly', ($field->fieldparams->get('llreadonly',true)?true:false));
		$debug = JFactory::getConfig()->get('debug',false);
		$doc = JFactory::getDocument();
		JHtml::_('jquery.framework',true);
		if (@$this->apikey = $this->params->get('apikey', false))
		{
			$latlon = (false===strpos($field->value,','))?array(0,0):explode(',', $field->value);
			$fieldid = 'plg_fields_location_' . $field->name . '_' . $field->id;
			$targetid = 'jform_com_fields_' . $field->name;
//			$searchbox = $field->fieldparams->get('searchbox',false)?'libraries=places':false;
//			if($searchbox) {
//				$urlvars[] = $searchbox;
//				JText::script('PLG_FIELDS_LOCATION_SEARCHBOX_PLACEHOLDER');
//			}
                        if(!$this->scriptAdded) {
                            $urlvars = array();
                            if($this->params->get('searchbox',false)) {
                                $urlvars[] = 'libraries=places';
                                JText::script('PLG_FIELDS_LOCATION_SEARCHBOX_PLACEHOLDER');
                            }
                            $urlvars[] = 'key='.$this->apikey;
                            $urlvars[] = 'sensor=false';
                            $doc->addScript('//maps.googleapis.com/maps/api/js?'.implode('&',$urlvars));
                            $doc->addScriptVersion(JURI::root(true).'/media/plg_fields_location/plg_fields_location'.($debug?'':'.min').'.js');
                            $this->scriptAdded = true;
                        }
			$options = array(
				'zoom'=>$field->fieldparams->get('editzoom', 1),
				'center'=>array($latlon[0]?:0, $latlon[1]?:0),
				'mapTypeId'=>$field->fieldparams->get('maptype', 'ROADMAP')
			);
                        if($this->params->get('searchbox',0) && $field->fieldparams->get('searchbox',0)) {
                            $options['searchbox'] = 1;
                        }
			$doc->addScriptOptions('plg_fields_location_'.$field->id,$options);
			$width = $field->fieldparams->get('editwidth', '400px');
			$height = $field->fieldparams->get('editheight', '300px');
			$doc->addStyleDeclaration('#' . $fieldid . ' { width: ' . ($width == 'auto' ? '100%' : $width) . '; height: ' . ($height == 'auto' ? '100%' : $height) . '; margin-bottom: 20px; }');
			$doc->addScriptDeclaration('jQuery(document).ready(function($){window.plg_fields_location.registerField('.$field->id.',"'.$fieldid.'","'.$targetid.'");});');
		}
		
		return $fieldNode;
	}

	public function createStaticMapURL($latlon, $zoom, $width, $height) {
		$size = array(str_replace(array('px','auto'),array('','400'), $width), str_replace(array('px','auto'),array('','300'), $height));
		$url = '//maps.googleapis.com/maps/api/staticmap?';
		$params = array();
		$params[] = 'center=' . $latlon;
		$params[] = 'zoom=' . $zoom;
		$params[] = 'size=' . implode("x", $size);
		$params[] = 'key=' . $this->params->get('staticapikey', false);
		$params[] = 'markers=' . $latlon;
		return $url . implode("&", $params);
	}

}
